=========
timescale
=========

|Language|
|License|
|PyPI Version|
|Anaconda-Server|
|Documentation Status|

.. |Language| image:: https://img.shields.io/pypi/pyversions/pyTMD?color=green
   :target: https://www.python.org/

.. |License| image:: https://img.shields.io/github/license/tsutterley/timescale
   :target: https://github.com/tsutterley/timescale/blob/main/LICENSE

.. |PyPI Version| image:: https://img.shields.io/pypi/v/timescale.svg
   :target: https://pypi.python.org/pypi/timescale/

.. |Anaconda-Server| image:: https://img.shields.io/conda/vn/conda-forge/timescale
   :target: https://anaconda.org/conda-forge/timescale

.. |Documentation Status| image:: https://readthedocs.org/projects/timescale/badge/?version=latest
   :target: https://timescale.readthedocs.io/en/latest/?badge=latest

Python tools for time and astronomical calculations

Dependencies
############

- `dateutil: powerful extensions to datetime <https://dateutil.readthedocs.io/en/stable/>`_
- `lxml: processing XML and HTML in Python <https://pypi.python.org/pypi/lxml>`_
- `numpy: Scientific Computing Tools For Python <https://www.numpy.org>`_
- `scipy: Scientific Tools for Python <https://www.scipy.org/>`_
- `setuptools_scm: manager for python package versions using scm metadata <https://pypi.org/project/setuptools-scm>`_

References
##########

    T. C. Sutterley, T. Markus, T. A. Neumann, M. R. van den Broeke, J. M. van Wessem, and S. R. M. Ligtenberg,
    "Antarctic ice shelf thickness change from multimission lidar mapping", *The Cryosphere*,
    13, 1801-1817, (2019). `doi: 10.5194/tc-13-1801-2019 <https://doi.org/10.5194/tc-13-1801-2019>`_

Download
########

| The program homepage is:
| https://github.com/tsutterley/timescale
| A zip archive of the latest version is available directly at:
| https://github.com/tsutterley/timescale/archive/main.zip

Disclaimer
##########

This package includes software developed at NASA Goddard Space Flight Center (GSFC) and the University of Washington Applied Physics Laboratory (UW-APL).
It is not sponsored or maintained by the Universities Space Research Association (USRA), AVISO or NASA.
The software is provided here for your convenience but *with no guarantees whatsoever*.

Credits
#######

This project contains work and contributions from the `scientific community <./CONTRIBUTORS.rst>`_.

License
#######

The content of this project is licensed under the `Creative Commons Attribution 4.0 Attribution license <https://creativecommons.org/licenses/by/4.0/>`_ and the source code is licensed under the `MIT license <LICENSE>`_.
